read2000.htm

## UK DATA ARCHIVE: IMPORTANT STUDY INFORMATION

### Study Number 2000 - Family Life and Work Experience Before 1918, 1870-1973

### Legal Agreement on Condition of Use

In accordance with the depositor's wishes, these data were made open (no registration required). The UK Data Archive approved the decision to open the data. Participants were interviewed in the 1970s when they were 70 years old or older; all were deceased by 2014.

### Privacy Impact Assessment

The UK Data Archive follows best practice guidance in the field of social science data sharing, taking its lead from the Office of National Statistics. Data owners and producers are responsible for signing off on confidentiality, following their own in-house protocols. For example, each government department may have its own classification system for data release of data and follow a bespoke standard. The Archive undertakes further routine checks on data to ensure the data meet our own confidentiality standards and match the type of licensing selected by the data depositor. Key survey variables are identified and checked for basic disclosure risk following the UK Government Statistical Service (GSS) Disclosure Control Guidance for Microdata Produced from Social Surveys. Release of other kinds of data, such as textual data, is approved the owner/producer and is further checked by the Archive for disclosive information that may potentially be detrimental to meeting the original terms and conditions of the research and participant consent. The Archive follows the Information Commissioner's Office (ICO) Anonymisation: Managing Data Protection Risk Code of Practice.

### UK Data Archive Processing Standards

The data were processed to the UK Data Archive's A* standard. This is the Archive's highest processing standard. This means that an extremely rigorous and comprehensive series of checks was carried out to ensure the quality of the data and documentation. in addtion, any data or documentation that breached confidentiality rules were altered or suppressed to preserve anonymity (see Privacy Impact Assessment statement above).

- Qualitative materials: thorough checks were made to qualitative interview transcripts to ensure that they were complete. Paper transcripts were scanned to digital format, checked and proof-read then converted to Adobe Acrobat PDF, and a data list was produced.
- Quantitative materials: thorough checks were made to ensure the logical integrity of the data. The number of cases and variables were checked and verified with the depositor's records; all variables and values were labelled where possible; nominal (categorical) variables were checked to ensure that values fell within the range defined by value labels or in the documentation.
- Documentation: electronic and paper documentation supplied with this study has been incorporated into the UK Data Archive User Guide, in Adobe PDF format. The conversion programs used were the latest versions of Adobe Acrobat for electronic documentation, with any paper documentation scanned to .TIFF format and converted to PDF. The Data List is also supplied in MS Excel format to allow subsetting and filtering. All PDF documentation files are fully bookmarked.

### Subsequent Enhancements

- In 2005, the study interview transcript files were further enhanced. Adobe PDF files were manually converted to XML and additional editing was done to ensure complete accuracy of speaker tags and turn-taking. Some non-Unicode-compliant characters were also removed from the texts.
- In 2013-2014, as part of the Digital Futures project, these files were further enhanced to prepare them for ingest into QualiBank. Enhancement included the addition of Qualitative Data Exchange Format(QuDEx) compliant metadata as well as Text Encoding Initiative (TEI) metadata. Minor errors in the XML files were also found and corrected.

### Audio file availability

Audio files are available on request. Contact the Helpdesk in the first instance.